@@ -99,13 +99,13 @@ Algorithm::Easing::Backdraft - Calculate eased translations between two positive
 =head2 ease_none
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_none($t,$b,$c,$d);
 
@@ -116,13 +116,13 @@ This method is used for a linear translation between two positive real whole int
 =head2 ease_in
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_in($t,$b,$c,$d);
 
@@ -133,13 +133,13 @@ This method is used to ease in between two positive real whole integers as an in
 =head2 ease_out
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_out($t,$b,$c,$d);
 
@@ -150,13 +150,13 @@ This method is used to ease out between two positive real whole integers as an i
 =head2 ease_both
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
