@@ -1,6 +1,6 @@
 package Algorithm::Easing::Exponential;
 
-use Moo;
+use Moose;
 
 use Math::Trig qw(:pi);
 
@@ -66,8 +66,6 @@ Algorithm::Easing::Exponential - Calculate eased translations between two positi
 
 =head1 SYNOPSIS
 
-        ## with mediator
-
         use Algorithm::Easing;
         use Algorithm::Easing::Exponential;
 
@@ -105,13 +103,13 @@ Algorithm::Easing::Exponential - Calculate eased translations between two positi
 =head2 ease_none
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_none($t,$b,$c,$d);
 
@@ -122,13 +120,13 @@ This method is used for a linear translation between two positive real whole int
 =head2 ease_in
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_in($t,$b,$c,$d);
 
@@ -139,13 +137,13 @@ This method is used to ease in between two positive real whole integers as an in
 =head2 ease_out
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_out($t,$b,$c,$d);
 
@@ -156,13 +154,13 @@ This method is used to ease in between two positive real whole integers as an in
 =head2 ease_both
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
