@@ -1,6 +1,6 @@
 package Algorithm::Easing::Quadratic;
 
-use Moo;
+use Moose;
 
 use Math::Trig qw(:pi);
 
@@ -57,8 +57,6 @@ Algorithm::Easing::Quadratic - Calculate eased translations between two positive
 
 =head1 SYNOPSIS
 
-        ## with mediator
-
         use Algorithm::Easing;
         use Algorithm::Easing::Quadratic;
 
@@ -96,13 +94,13 @@ Algorithm::Easing::Quadratic - Calculate eased translations between two positive
 =head2 ease_none
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_none($t,$b,$c,$d);
 
@@ -113,13 +111,13 @@ This method is used for a linear translation between two positive real whole int
 =head2 ease_in
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_in($t,$b,$c,$d);
 
@@ -130,13 +128,13 @@ This method is used to ease in between two positive real whole integers as an in
 =head2 ease_out
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_out($t,$b,$c,$d);
 
@@ -147,13 +145,13 @@ This method is used to ease in between two positive real whole integers as an in
 =head2 ease_both
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
