@@ -95,13 +95,13 @@ Algorithm::Easing::Quintonion - Calculate eased translations between two positiv
 =head2 ease_none
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_none($t,$b,$c,$d);
 
@@ -112,13 +112,13 @@ This method is used for a linear translation between two positive real whole int
 =head2 ease_in
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_in($t,$b,$c,$d);
 
@@ -129,13 +129,13 @@ This method is used to ease in between two positive real whole integers as an in
 =head2 ease_out
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_out($t,$b,$c,$d);
 
@@ -146,13 +146,13 @@ This method is used to ease in between two positive real whole integers as an in
 =head2 ease_both
     Usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
